"""
This script replaces tabs with commas and adds specified
headers to the files.

NOTE: This script assumes no header - it does not check whether or
not a header already exists.
"""

import os
from anuga.utilities.system_tools import get_user_name, get_host_name
from time import localtime, strftime, gmtime
from anuga.lib.add_csv_header.add_csv_header import add_csv_header
#from add_csv_header import add_csv_header
from os.path import join, exists

#-------------------------------------------------------------------------------
# Directory setup
#-------------------------------------------------------------------------------

# this section needs to be updated to reflect the modelled community.
# Note, the user needs to set up the directory system accordingly
state = 'australia_ph2'
scenario_name = 'cooktown'
scenario_folder = scenario_name
ENV_INUNDATIONHOME = 'INUNDATIONHOME'
home = join(os.getenv(ENV_INUNDATIONHOME), 'data') # Absolute path for data folder
anuga_folder = join(home, state, scenario_folder, 'anuga')
topographies_folder = join(anuga_folder, 'topographies')


def replace_in_file(filename, instr, repstr):
    '''Replace one string with another in a file.'''
    
    # get the file contents
    fd = open(filename, 'r')
    lines = fd.readlines()
    fd.close()

    # convert list to one string
    newlines = ''.join(lines)
    
    # replace 'instr' with 'repstr'
    newlines = newlines.replace(instr, repstr)
    
    # write changed lines back to file
    fd = open(filename, 'w')
    fd.write(newlines)
    fd.close()

def reverse_depth(filename):
    '''Reverse sign of depths in x, y, elevation file'''

    # get the file contents
    fd = open(filename, 'r')
    lines = fd.readlines()
    fd.close()
    fd=open(filename,'w')
    for line in lines:
        fields = line.split(',')
        z = -float(fields[2])
        fd.write('%s, %s, %f\n' % (fields[0], fields[1], z))
    fd.close() 
   
# Elevation point files 
point_filenames = ['ahs100_0.xyz',
                   'ahs100_1.xyz',
                   'ahs100_2.xyz',
                   'ahs100_3.xyz',
                   'ahs100_4.xyz',
                   'ahs100_5.xyz',
                   'ahs100_6.xyz',
                   'ahs100_7.xyz',
                   'ahs100_8.xyz',
                   'ahs100_9.xyz',
                   'ahs100_10.xyz',
                   'ahs100_11.xyz',
                   'ahs100_12.xyz',
                   'ahs100_13.xyz'] # LADS data

headerlist = ['x', 'y', 'elevation']

for f in point_filenames:
    print 'replace tab with comma in file ', f
    replace_in_file(join(topographies_folder,f), '\t', ',')

    print 'Convert water depth to negative', f
    reverse_depth(join(topographies_folder,f))
    
    print 'Add headers to ', f
    add_csv_header(join(topographies_folder, f), headerlist)

    
    
