"""
Program to plot the results from the Phase 2 comparisions.
Compares stage height results from models run with best available data against those
using the Geoscience Australia 250 m bathymetry/elevation grid (2005). 


Creator: Jonathan Griffin
Created: 29 September 2009
"""
import os
import sys
from os.path import join
import csv

import matplotlib
matplotlib.use('Agg')
import pylab
from pylab import *
import numpy

path = r'/nas/gemd/georisk_models/inundation/data/australia_ph2/documents/250m comparisons'
path_list = []
model_list = ['BatemansBay', 'Busselton', 'Carnarvon', 'Geraldton', 'GoldCoast', 'Gosford', 'Hobart', 'Pt_hedland']

# Choose figure name here! This controls what is plotted
#figure_name = 'Phase2comparions_percent.png' # Plots the mean percentage difference in stage
#figure_name = 'Phase2comparions.png'   # Plots the absolute difference in stage
#figure_name = 'greens_law_comparision.png'   # Plots the absolute difference in stage compared to Greens Law
figure_name = 'greens_law_percent_comparision.png'   # Plots the percentage difference in stage compared to Greens Law

figure_folder = join(path, 'figures')
figure_path = join(figure_folder, figure_name)

plot_dict = {'BatemansBay':'x', 'Busselton':'^', 'Carnarvon':'x', 'Geraldton':'h', 'GoldCoast': 'v', 'Gosford':'+', 'Hobart':'^','Pt_hedland':'+'}
colour_dict = {'BatemansBay':'r', 'Busselton':'b', 'Carnarvon': 'b', 'Geraldton':'b', 'GoldCoast': 'r', 'Gosford':'r',  'Hobart':'r','Pt_hedland':'b'}

mean_100m_stage = {'BatemansBay': 1.10, 'Busselton': 0.98, 'Carnarvon': 2.03, 'Geraldton':0.95,
                   'GoldCoast': 2.22, 'Gosford': 1.86, 'Hobart': 2.05,'Pt_hedland': 0.77}
event_dict = {'BatemansBay': 58284, 'Busselton': 27283, 'Carnarvon': 27283, 'Geraldton':27283,
              'GoldCoast': 51469, 'Gosford': 51436, 'Hobart': 58260, 'Pt_hedland': 27283}

depth_list2 = [-60,-50,-40,-30,-20,-10,0,10]
twenty_m = [20,20,20,20,20,20,20,20]
fifty_m = [50,50,50,50,50,50,50,50]

for model in model_list:
    model_path = join(path, model, 'comparisons.csv')
    path_list.append(model_path)
#
pylab.cla()
counter = 0
for file_path in path_list:
    reader = csv.reader(open(file_path))
    header = reader.next()
    depth_index = header.index('VALUE_')
    stage_diff_index = header.index('STAGE_DIFF')
    orig_stage_index = header.index('stage_high_res_model')
    print depth_index, stage_diff_index, orig_stage_index
    
    depth = []
    stage_diff = []
    orig_stage = []
    for row in reader:
        depth.append(float(row[depth_index]))
        stage_diff.append(abs((float(row[stage_diff_index]))))
        orig_stage.append(float(row[orig_stage_index]))
    depth_dict = dict.fromkeys(depth).keys()

    # Establish dictionaries and lists
    stage_diff_dict = {}
    orig_stage_dict = {}
    percent_diff_dict = {}
    stage_diff_mean_dict = {}
    orig_stage_mean_dict = {}
    percent_diff_mean_dict = {}
    
    greens_law_dict = {}
    greens_law_percent_dict = {}    
    greens_law_mean_dict = {}
    greens_law_percent_mean_dict = {}
    

    key_list = []
    diff_mean_list = []
    percent_mean_list = []
    greens_law_diff_mean_list=[]
    greens_law_percent_mean_list=[]

    
    for key in depth_dict:

        #print 'key',key
        # Calculate Green's Law estimate
        greens_estimate = mean_100m_stage[model_list[counter]]*numpy.power((100.0/abs(key+0.001)),(0.25))
        #print 'greens_estimate', greens_estimate
        # Lists to store results
        stage_diff_list = []        
        orig_stage_list = []
        percent_diff_list = []
        greens_law_diff = []
        greens_law_percent = []
        
        # Loop through depths
        for i in range(len(depth)):
            if depth[i] == key:
                stage_diff_list.append(stage_diff[i])
                orig_stage_list.append(orig_stage[i])
                percent_diff_list.append((stage_diff[i]/orig_stage[i])*100)
                greens_law_diff.append(abs((orig_stage[i]-greens_estimate)))
                greens_law_percent.append(abs(((orig_stage[i]-greens_estimate)/orig_stage[i])*100))
                
        stage_diff_dict[key] = stage_diff_list
        orig_stage_dict[key] = orig_stage_list
        percent_diff_dict[key] = percent_diff_list
        greens_law_dict[key] = greens_law_diff
        greens_law_percent_dict[key] = greens_law_percent

        stage_diff_mean_dict[key] = numpy.mean(stage_diff_dict[key])
        orig_stage_mean_dict[key] = numpy.mean(orig_stage_dict[key])
        percent_diff_mean_dict[key] = numpy.mean( percent_diff_dict[key])
        greens_law_mean_dict[key] = numpy.mean(greens_law_dict[key])
        greens_law_percent_mean_dict[key] = numpy.mean(greens_law_percent_dict[key])
        
        key_list.append(key)
        diff_mean_list.append(stage_diff_mean_dict[key])
        percent_mean_list.append(percent_diff_mean_dict[key])
        greens_law_diff_mean_list.append(greens_law_mean_dict[key])
        greens_law_percent_mean_list.append(greens_law_percent_mean_dict[key])
        #print 'greens_law_diff_mean_list', greens_law_diff_mean_list
    pylab.semilogy()
    pylab.xlabel('Depth (m)') 
    
    if figure_name == 'Phase2comparions.png':
        pylab.title('Mean difference in stage height (m)')
        pylab.ylabel('Difference (m)')
        pylab.scatter(key_list,diff_mean_list, marker = plot_dict[model_list[counter]],color = colour_dict[model_list[counter]])
        
    if figure_name == 'Phase2comparions_percent.png':
        pylab.title('Mean percentage difference in stage height')
        pylab.ylabel('Difference %')
        pylab.scatter(key_list,percent_mean_list, marker = plot_dict[model_list[counter]],color = colour_dict[model_list[counter]])
        pylab.plot(depth_list2,twenty_m, color = 'black')
        
    if figure_name == 'greens_law_comparision.png':
        pylab.title('Greens Law mean difference in stage height')
        pylab.ylabel('Difference (m)')
        pylab.scatter(key_list,greens_law_diff_mean_list, marker = plot_dict[model_list[counter]],color = colour_dict[model_list[counter]])
        
    if figure_name == 'greens_law_percent_comparision.png':
        pylab.title('Greens Law mean percentage difference in stage height')
        pylab.ylabel('Difference %')
        pylab.scatter(key_list,greens_law_percent_mean_list, marker = plot_dict[model_list[counter]],color = colour_dict[model_list[counter]])
        pylab.plot(depth_list2,twenty_m, color = 'black')
    counter+=1

if figure_name == 'Phase2comparions.png':
   pylab.text(-58, 50, 'East Coast', color = 'r')
   pylab.text(-58, 30, 'West Coast', color = 'b')
 
if figure_name == 'Phase2comparions_percent.png':
    pylab.text(-58, 600, 'East Coast', color = 'r')
    pylab.text(-58, 400, 'West Coast', color = 'b')
    pylab.text(-58, 22, '20%')

if figure_name == 'greens_law_comparision.png':
    pylab.text(-58, 60, 'East Coast', color = 'r')
    pylab.text(-58, 40, 'West Coast', color = 'b')

if figure_name == 'greens_law_percent_comparision.png':
    pylab.text(-58, 5000, 'East Coast', color = 'r')
    pylab.text(-58, 3000, 'West Coast', color = 'b')
    pylab.text(-58, 22, '20%')

pylab.savefig(figure_path)


