""" This code calculates the time differences for 250 m adn
high resolution models

Creator: Jonathan Griffin, Geoscience Australia
Created: 10 November 2009
"""

import os
import sys
from os.path import join
import csv

import matplotlib
matplotlib.use('Agg')
import pylab
from pylab import *
import numpy

path = r'/nas/gemd/georisk_models/inundation/data/'
figure_path = r'/nas/gemd/georisk_models/inundation/data/australia_ph2/documents/250m comparisons/figures'
figure_name = 'Phase2_time_comp.png'
figure_file_path = join(figure_path, figure_name)

PHed1 = r'/nas/gemd/georisk_models/inundation/data/western_australia/pt_hedland_tsunami_scenario_2009/anuga/outputs/20081125_135917_run_final_0_27283_250m_none_lfountai'
PHed2 = r'/nas/gemd/georisk_models/inundation/data/western_australia/pt_hedland_tsunami_scenario_2009/anuga/outputs/20081211_095614_run_final_0.0_27283_alpha0.1_jgriffin'
Bus1 = r'/nas/gemd/georisk_models/inundation/data/western_australia/busselton_tsunami_scenario/anuga/outputs/20091210_133449_run_final_0.6_27255_Bt_250m_jgriffin'
Bus2 = r'/nas/gemd/georisk_models/inundation/data/western_australia/busselton_tsunami_scenario/anuga/outputs/20090403_092302_run_final_0.6_27255_Bt_kvanputt'
Car1 = r'/nas/gemd/georisk_models/inundation/data/western_australia/carnarvon_tsunami_scenario/anuga/outputs/20100112_172321_run_final_0_27255_250m_jgriffin'
Car2 = r'/nas/gemd/georisk_models/inundation/data/western_australia/carnarvon_tsunami_scenario/anuga/outputs/20090327_154824_run_final_0_27255_Bt_kvanputt'
Ger1 = r'/nas/gemd/georisk_models/inundation/data/western_australia/geraldton_tsunami_scenario/anuga/outputs/20091210_174442_run_final_0_27255_Bt_250m_jgriffin'
Ger2 = r'/nas/gemd/georisk_models/inundation/data/western_australia/geraldton_tsunami_scenario/anuga/outputs/20090327_160043_run_final_0_27255_Bt_kvanputt'

Gos1 = r'/nas/gemd/georisk_models/inundation/data/new_south_wales/gosford_tsunami_scenario_2009/anuga/outputs/20090915_094930_run_final_0.0_51436_250m_jgriffin'
Gos2 = r'/nas/gemd/georisk_models/inundation/data/new_south_wales/gosford_tsunami_scenario_2009/anuga/outputs/20090615_160610_run_final_0.0_51436_jgriffin'
BBay1 = r'/nas/gemd/georisk_models/inundation/data/new_south_wales/batemans_bay_tsunami_scenario_2009/anuga/outputs/20090601_172248_run_final_0.0_58284__250m_jgriffin'
BBay2 = r'/nas/gemd/georisk_models/inundation/data/new_south_wales/batemans_bay_tsunami_scenario_2009/anuga/outputs/20090520_145616_run_final_0.0_58284_jgriffin'
Gold1 =r'/nas/gemd/georisk_models/inundation/data/queensland/gold_coast_tsunami_scenario_2009/anuga/outputs/20090605_120328_run_final_0_250m_51469_lfountai'
Gold2 =r'/nas/gemd/georisk_models/inundation/data/queensland/gold_coast_tsunami_scenario_2009/anuga/outputs/20090508_150215_run_final_0_51469_lfountai'
Hob1 = r'/nas/gemd/georisk_models/inundation/data/tasmania/hobart_tsunami_scenario_2009/anuga/outputs/20090930_151227_run_final_0_58260_250m_jgriffin'
Hob2 = r'/nas/gemd/georisk_models/inundation/data/tasmania/hobart_tsunami_scenario_2009/anuga/outputs/20090714_162136_run_final_0_58260_None_kvanputt'

low_res_list = [PHed1, Bus1, Car1, Ger1, Gos1, BBay1, Gold1, Hob1]
high_res_list = [PHed2, Bus2, Car2, Ger2, Gos2, BBay2, Gold2, Hob2]
depth_list = [0,-10,-20,-30,-40,-50]

marker_list = ['x','^', 'x', '+', 'x','^', 'x', '+' ]
colours = ['b','b','b','b','r','r','r','r']


for i in range(len(low_res_list)):
    low_res_time_list = []
    high_res_time_list = []
    for depth in depth_list:
        file_path = low_res_list[i]+'/gauge_'+str(depth)+'.csv'
        reader = csv.reader(open(file_path))
        header = reader.next()
        initial_values = reader.next()
        time = 0
        for row in reader:
            if time != 0:
                break
            if abs(float(row[2]))> abs(float(initial_values[2]))+0.01:
                time = row[0]
                break
        low_res_time_list.append(float(time))

    for depth in depth_list:
        file_path = high_res_list[i]+'/gauge_'+str(depth)+'.csv'
        reader = csv.reader(open(file_path))
        header = reader.next()
        initial_values = reader.next()
        time = 0
        for row in reader:
            if time != 0:
                break
            if abs(float(row[2]))> abs(float(initial_values[2]))+0.01:
                time = row[0]
                break
        high_res_time_list.append(float(time))

    time_diff = []
    for j in range(len(low_res_time_list)):
        if high_res_time_list[j] ==0:
            high_res_time_list[j]=-999999
        if low_res_time_list[j] ==0:
            low_res_time_list[j]=999999
        time_diff.append(abs((high_res_time_list[j] - low_res_time_list[j])))
    print 'low_res_time_list', low_res_time_list
    print 'high_res_time_list', high_res_time_list       
    print time_diff
    for j in range(len(time_diff)):
        time_diff[j] = time_diff[j]/60

    pylab.scatter(depth_list,time_diff, marker = marker_list[i], color = colours[i])
#pylab.semilogy([0,1])
        
pylab.axis([-60,10,0,40])
pylab.title('Difference in arrival times (minutes)')
pylab.ylabel('Difference (minutes)')
pylab.xlabel('Depth')
pylab.text(-58, 37, 'East Coast', color = 'r')
pylab.text(-58, 35, 'West Coast', color = 'b')
pylab.savefig(figure_file_path)
